#!/usr/bin/env bash

install_basic_postgres_charts() {
    install_rabbitmq_chart $1
    install_postgis_chart $1
    install_grb_chart $1
    install_geo2grid_chart $1
    install_tile_gen_chart $1
    install_mapserver_chart $1
    install_mapcache_chart $1
    install_client_chart $1
    debug "$(helm -n $ns list)"
}

set -e
source ci_tests/_tests_common.sh
ns=$(./helpers/get_namespace.sh)
source ci_tests/get_release_names.sh
install_basic_postgres_charts "ci_tests/basic_postgres"

# give kubernetes a bit to create the resources
debug "Waiting for Kubernetes to deploy and schedule components..."
sleep 60
debug "Done waiting"

debug "Getting GRB pod name"
GRB_POD_NAME=$(get_pod_name "${GRB_RELEASE_NAME}")
debug "GRB pod name: ${GRB_POD_NAME}"
GEO2GRID_POD_NAME=$(get_pod_name "${GEO2GRID_RELEASE_NAME}")
debug "Geo2Grid pod name: ${GEO2GRID_POD_NAME}"
TILEGEN_POD_NAME=$(get_pod_name "${TILEGEN_RELEASE_NAME}")
debug "Tile Generation pod name: ${TILEGEN_POD_NAME}"
MAPSERVER_POD_NAME=$(get_pod_name "${MAPSERVER_RELEASE_NAME}")
debug "MapServer pod name: ${MAPSERVER_POD_NAME}"
MAPCACHE_POD_NAME=$(get_pod_name "${MAPCACHE_RELEASE_NAME}")
debug "MapCache pod name: ${MAPCACHE_POD_NAME}"
CLIENT_POD_NAME=$(get_pod_name "${CLIENT_RELEASE_NAME}")
debug "Client pod name: ${CLIENT_POD_NAME}"

wait_for_pod ${GRB_POD_NAME} || error "GRB pod was never ready"
run_grb_checks || error "GRB checks failed"
wait_for_pod ${GEO2GRID_POD_NAME} || error "Geo2Grid pod was never ready"
run_geo2grid_checks || error "Geo2Grid checks failed"
wait_for_pod ${TILEGEN_POD_NAME} || error "Tile Gen pod was never ready"
run_tile_gen_checks || error "Tile Generation checks failed"
wait_for_pod ${MAPSERVER_POD_NAME} || error "MapServer pod was never ready"
run_mapserver_checks || error "MapServer checks failed"
wait_for_pod ${MAPCACHE_POD_NAME} || error "MapCache pod was never ready"
run_mapcache_checks || error "MapCache checks failed"
wait_for_pod ${CLIENT_POD_NAME} || error "Client pod was never ready"
run_client_checks || error "Client checks failed"


